# Contributing to FatPy

Thank you for considering contributing to FatPy!

## Quick Start

1. Fork the repository
2. Clone your fork: `git clone https://github.com/your-username/FatPy.git`
3. Create a branch: `git checkout -b my-feature-branch`
4. Write tests for your feature
5. Implement the feature
6. Submit a pull request

## Development Setup

For detailed setup instructions, see the [Installation Guide](install.md).

## Test-Driven Development

FatPy follows Test-Driven Development (TDD) principles:

1. Write tests that define expected behavior
2. Verify tests fail (red phase)
3. Implement code to make tests pass (green phase)
4. Refactor while maintaining test coverage
5. Repeat

For more details, see the [Testing Guide](testing.md).

## Coding Standards

This project uses:

- **Ruff** - Linting and formatting
- **MyPy** - Type checking
- **Pre-commit** - Automated quality checks

All code should be typed, documented, and follow the [Code Style Guide](code_style.md).

## Testing

```sh
# Run all tests
pytest

# Test with coverage
pytest --cov=src/fatpy
```

## Documentation

- Update docs for API changes
- Add docstrings to new code
- Include examples where helpful

See the [Documentation Guide](documentation.md) for more details.

## Pull Request Process

1. Ensure tests pass and code quality checks succeed
2. Update relevant documentation
3. Link any related issues
4. Wait for review feedback

## Code of Conduct

All contributors must follow our [Code of Conduct](code_of_conduct.md).

## Questions?

Create an issue or email jan.vyborny2@gmail.com.

Thank you for contributing to FatPy!
