# Development Guide

Welcome to the FatPy development guide. This section provides resources to help you contribute to the FatPy project effectively.

## Getting Started

If you're new to FatPy development, we recommend starting with these resources:

- [Installation Guide](install.md) - Set up your development environment
- [Contributing Guide](contributing.md) - Learn how to contribute to the project
- [Code of Conduct](code_of_conduct.md) - Understand our community standards

## Development Resources

- [Code Style](code_style.md) - Coding standards and style guidelines
- [Documentation](documentation.md) - Documentation best practices and guidelines
- [Testing](testing.md) - How to write and run tests
- [CI/CD Process](ci_cd.md) - Information about our continuous integration workflow

## Project Structure

For a detailed overview of the project structure, see the [API Reference](../api/index.md).

## Development Workflow

Following Test-Driven Development (TDD) principles:

1. **Write tests first** - Define the expected behavior before implementing
2. **Set up your environment** - Follow the [installation guide](install.md)
3. **Create a feature branch** - `git checkout -b feature-name`
4. **Implement the feature** - Follow the [code style guide](code_style.md)
5. **Run and refine tests** - See the [testing guide](testing.md)
6. **Document your changes** - Update the [documentation](documentation.md)
7. **Submit a pull request** - See the [contributing guide](contributing.md)

## Getting Help

If you encounter issues or need assistance with development, you can:

- Create an issue in the [GitHub repository](https://github.com/vybornak2/fatpy/issues)
- Contact the maintainers at jan.vyborny2@gmail.com

Thank you for contributing to FatPy!
